@@ -10,6 +10,8 @@ try:
     from rich.console import Console
     from rich.table import Table
     from rich.panel import Panel
+
+    console = Console()
 except Exception as e:
     pass
 
@@ -53,6 +55,8 @@ class Meteo:
 
     EXIT_ON_NO_INTERNET = False
     CHECK_INTERNET = False
+    DEBUG = False
+    print = console.print
 
     headers = {
         "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:32.0) Gecko/20100101 Firefox/32.0",
@@ -253,6 +257,7 @@ class Meteo:
 
             cols = [ele.text.strip() for ele in cols]
 
+
             if i == 0: # first row
                 month1 = cols[0].lower()
                 month2 = cols[1].lower()
@@ -269,7 +274,6 @@ class Meteo:
                 m2_hour = int(cols[6])
                 m2_min = int(cols[7])
 
-
                 code_lookup = {
                     'N.M': 'new moon',
                     'F.Q': 'first quarter',
@@ -277,27 +281,20 @@ class Meteo:
                     'L.Q': 'last quarter'
                 }
 
-                if all([
-                    m1_phase, 
-                    m1_date, 
-                    m1_hour,
-                    m1_min,
-                    m2_phase, 
-                    m2_date, 
-                    m2_hour,
-                    m2_min
-                    ]):
-                    phase = code_lookup[m1_phase]
-                    data[month1][phase] = {
-                        "date": m1_date, 
-                        "hour": m1_hour,
-                        "minute": m1_min
-                        }
-                    data[month2][phase] = {
-                        "date": m1_date, 
-                        "hour": m1_hour,
-                        "minute": m1_min
-                        }
+                phase1 = code_lookup[m1_phase]
+                data[month1][phase1] = {
+                    "date": m1_date, 
+                    "hour": m1_hour,
+                    "minute": m1_min
+                    }
+
+                phase2 = code_lookup[m2_phase]
+                data[month2][phase2] = {
+                    "date": m2_date, 
+                    "hour": m2_hour,
+                    "minute": m2_min
+                    }
+
 
         if print_:
             console = Console()
@@ -534,119 +531,180 @@ class Meteo:
         data = {'eclipses':[]}
         year = None
         eclipse_info = {}
+        all_tables = []
+        equinoxes = []
+        # cls.print(str(len(tables)))
         for table_index, table in enumerate(tables):
-            table_body = table.find("tbody")
+            current_list = table.text.strip().split('\n')
+            current_list = [e for e in current_list if bool(e.strip())]
+            if table_index == 0:
+                pass 
 
-            rows = table_body.find_all("tr")
-            for i, row in enumerate(rows):
-                cols = row.find_all("td")
+            elif table_index == len(tables)-1:
+                equinoxes = current_list
+            else:
+                
+                all_tables += current_list
+        '''
+        [
+         {
+            'end': {'date': 1, 'hour': 2, 'minute': 37, 'month': 'may'},
+            'info': 'The eclipse will not be visible in Mauritius, Rodrigues, St. Brandon and Agalega.',
+            'start': {'date': 30, 'hour': 22, 'minute': 45, 'month': 'april'},
+            'status': 'partial',
+            'type': 'sun'
+         },
+         ...
+         {
+            'end': {'date': 8, 'hour': 17, 'minute': 56, 'month': 'november'},
+            'info': 'The eclipse will not be visible in Mauritius, Rodrigues, St. Brandon and Agalega.',
+            'start': {'date': 8, 'hour': 12, 'minute': 2, 'month': 'november'},
+            'status': 'total',
+            'type': 'moon'
+         }
+        ]
+        '''
+        eclipse_info = []
+        
+        if cls.DEBUG:
+            cls.print(all_tables)
+        '''
+        [
+            'Annular-Total eclipse of the Sun - April 20',
+            'The eclipse begins on 20 April at 05h34 and ends on 20 April at 10h59.',
+            'The penumbral part of the eclipse will be visible in Mauritius, Rodrigues, St. Brandon but will not be visible in 
+        Agalega.',
+            'Penumbral eclipse of the Moon - May 05',
+            'The eclipse begins on 05 May at 19h12 and ends at 23h33.',
+            'The eclipse will be visible in Mauritius, Rodrigues, St. Brandon and Agalega.',
+            'Annular eclipse of the Sun - October 14-15',
+            'The eclipse begins on 14 October at 19h04 and ends on 15 October at 00h55.',
+            'The eclipse will not be visible in Mauritius, Rodrigues, St. Brandon and Agalega.',
+            'Partial eclipse of the Moon - October 28-29',
+            'The eclipse begins on 28 October at 23h34 and ends on 29 October at 02h28.',
+            'The eclipse will be visible in Mauritius, Rodrigues, St. Brandon and Agalega.'
+        ]
+        '''
+        for table_index, row in enumerate(all_tables):
+            info = {}
+            if (
+                ('eclipse of the' in row.casefold()) and
+                ('-' in row.casefold())
+                ):
+                info['title'] = row.split(' - ')[0].strip()
+                info['info'] = all_tables[table_index+2]
+                if 'sun' in info['title'].casefold():
+                    info['type'] = 'sun'
+                elif 'moon' in info['title'].casefold():
+                    info['type'] = 'moon'
+                info['status'] = info['title'].casefold().split()[0].strip()
 
-                cols = [ele.text.strip() for ele in cols]
+                # info['date'] = row.split(' - ')[1].strip()
 
-                if table_index == len_tables - 1:
-                    # ['EQUINOXES and SOLSTICES - 2022']
-                    # ['Equinoxes\xa0\xa0\xa0 :March 20 at 19h33 and September 23 at 05h03.']
-                    # ['Solstices\xa0\xa0\xa0 :June 21 at 13h13 and December 22 at 01h48.']
+                next_row = all_tables[table_index+1]
 
-                    if i == 0:
-                        year = cols[0].split('-')[1].strip()
-                        year = int(year)
-                    else:
-                        split_at_colon = cols[0].split(':')
-                        label = split_at_colon[0].strip().lower()
-                        dates = split_at_colon[1].split('and')
-                        date1 = dates[0].strip().split('at')
-                        date2 = dates[1].strip().split('at')
+                next_row_words = next_row.split()
+                for i, word in enumerate(next_row_words):
+                    if word == 'begins':
+                        if next_row_words[i+1] == 'on':
+                            info['start'] = {}
+                            info['start']['date'] = next_row_words[i+2]
+                            info['start']['month'] = next_row_words[i+3]
+                            info['start']['time'] = next_row_words[i+5]
+                    if word == 'ends':
+                        if next_row_words[i+1] == 'on':
+                            info['end'] = {}
+                            info['end']['date'] = next_row_words[i+2]
+                            info['end']['month'] = next_row_words[i+3]
+                            info['end']['time'] = next_row_words[i+5]
+                        elif next_row_words[i+1] == 'at':
+                            info['end'] = {}
+                            info['end']['date'] = info['start']['date']
+                            info['end']['month'] = info['start']['month']
+                            info['end']['time'] = next_row_words[i+2]
 
-                        data[label] = [
-                                {
-                                    'day': int(date1[0].strip().split()[1]),
-                                    'month': date1[0].strip().split()[0].lower(),
-                                    'year': year,
-                                    'hour': int(date1[1].strip().split('h')[0]),
-                                    'minute': int(date1[1].strip().split('h')[1].strip('.'))
-                                },
-                                {
-                                    'day': int(date2[0].strip().split()[1]),
-                                    'month': date2[0].strip().split()[0].lower(),
-                                    'year': year,
-                                    'hour': int(date2[1].strip().split('h')[0]),
-                                    'minute': int(date2[1].strip().split('h')[1].strip('.'))
-                                },
-                            ]
-                else:
-                    
-                    if len(cols) == 1:
-                        
-                        # ['Total eclipse of the Moon - November 08']
-                        # ['The eclipse begins on 08 November at 12h02 and ends at 17h56.']
-                        # ['The eclipse will not be visible in Mauritius, Rodrigues, St. Brandon and Agalega.']
-                        
-                        
-                        if i == 0:
-                            eclipse_info['status'] = cols[0].split('-')[0].strip().split()[0].lower()
-                            eclipse_info['type'] = cols[0].split('-')[0].strip().split()[-1].lower()
+                eclipse_info.append(info)
 
-                        elif i == 1:
-                            data_part = cols[0][len('The eclipse begins on '):].strip('.')
-                            data_list = data_part.split()
+        if cls.DEBUG:
+            cls.print(equinoxes)
+        '''
+        [
+            'EQUINOXES and SOLSTICES - 2023',
+            'Equinoxes\xa0\xa0\xa0 :\xa0 \xa0March 21 at 01h24 and September 23 at 10h50.',
+            'Solstices\xa0\xa0\xa0 :\xa0 \xa0June 21 at 18h57 and December 22 at 07h27.'
+        ]
+        '''
+        equinox = [e.strip().casefold().strip('.') for e in equinoxes[1].split()]
+        solstice = [e.strip().casefold().strip('.') for e in equinoxes[2].split()]
+        year = equinoxes[0].split(' - ')[1].strip().casefold()
+        year = int(year)
+        '''
 
-                            if len(data_list) == 8:   
-                                # 08 November at 12h02 and ends at 17h56
-                                date = int(data_list[0])
-                                month = data_list[1].lower()
-                                start_hour = int(data_list[3].split('h')[0])
-                                start_minute = int(data_list[3].split('h')[1])
-                                end_hour = int(data_list[7].split('h')[0])
-                                end_minute = int(data_list[7].split('h')[1])
+        >>> get_equinoxes()
+        [
+         {
+            'day': 20, 'hour': 19, 'minute': 33, 'month': 'march', 'year': 2022
+         },
+         {
+          'day': 23, 'hour': 5, 'minute': 3, 'month': 'september', 'year': 2022
+         }
+        ]
 
-                                eclipse_info['start'] = {
-                                    'date': date,
-                                    'month': month,
-                                    'hour': start_hour,
-                                    'minute': start_minute
-                                }
-                                eclipse_info['end'] = {
-                                    'date': date,
-                                    'month': month,
-                                    'hour': end_hour,
-                                    'minute': end_minute
-                                }
+        >>> get_solstices()
+        [
+         {
+            'day': 21, 'hour': 13, 'minute': 13, 'month': 'june', 'year': 2022
+         },
+         {
+            'day': 22, 'hour': 1, 'minute': 48, 'month': 'december', 'year': 2022
+         }
+        ]'''
+        equinox_info = None
+        for i, e in enumerate(equinox):
+            if e == 'and':
+                equinox_info = [
+                {
+                    'day': int(equinox[i-3]),
+                    'month': equinox[i-4],
+                    'year': year,
+                    'hour': int(equinox[i-1].split('h')[0]),
+                    'minute': int(equinox[i-1].split('h')[1]),
+                },
+                {
+                    'day': int(equinox[i+2]),
+                    'month': equinox[i+1],
+                    'year': year,
+                    'hour': int(equinox[i+4].split('h')[0]),
+                    'minute': int(equinox[i+4].split('h')[1]),
+                },
+                ] 
 
 
-                            else:
-                                # 30 April at 22h45 and ends on 01 May at 02h37
-                                date = int(data_list[0])
-                                month = data_list[1].lower()
-                                start_hour = int(data_list[3].split('h')[0])
-                                start_minute = int(data_list[3].split('h')[1])
-                                end_date = int(data_list[7])
-                                end_month = data_list[8].lower()
-                                end_hour = int(data_list[10].split('h')[0])
-                                end_minute = int(data_list[10].split('h')[1])
+        solstice_info = None
+        for i, e in enumerate(equinox):
+            if e == 'and':
+                solstice_info = [
+                {
+                    'day': int(solstice[i-3]),
+                    'month': solstice[i-4],
+                    'year': year,
+                    'hour': int(solstice[i-1].split('h')[0]),
+                    'minute': int(solstice[i-1].split('h')[1]),
+                },
+                {
+                    'day': int(solstice[i+2]),
+                    'month': solstice[i+1],
+                    'year': year,
+                    'hour': int(solstice[i+4].split('h')[0]),
+                    'minute': int(solstice[i+4].split('h')[1]),
+                },
+                ] 
 
-                                eclipse_info['start'] = {
-                                    'date': date,
-                                    'month': month,
-                                    'hour': start_hour,
-                                    'minute': start_minute
-                                }
-                                eclipse_info['end'] = {
-                                    'date': end_date,
-                                    'month': end_month,
-                                    'hour': end_hour,
-                                    'minute': end_minute
-                                }
-
-
-                        elif i == 2:
-                            eclipse_info['info'] = cols[0]
-
-                            data['eclipses'].append(eclipse_info)
-
-                            eclipse_info = {}
-
-        return data
+        return {
+            'eclipses': eclipse_info,
+            'equinoxes': equinox_info,
+            'solstices': solstice_info
+        }
 
     @classmethod
     def get_eclipses(cls):
